// --- gttest.pov ---
//
// verification testing for GT integration with Genesis Toolkit
// Genesis Toolkit is (C) 1998-2002
// http://www.schrammel.org/
//
// GT is (C) 2002
// http://www.bowlvisions.com/
// ithaqua@inreach.com
//

// standard POV-Ray distro
//
#include "colors.inc"
#include "stones.inc"

// local custom - GT distro, color defs
//
#include "gtnature.inc"

// The named object is defined in veg.inc,
// part of Genesis Toolkit distribution...
//
#if(1)
#include "veg.inc"

// ... and in local m2veg.inc, for test only.
//
#else
#include "m2veg.inc"
#end

// Genesis Toolkit generated object-placement file
// gttest.inc     objects default Gen output
// gttestnx.inc   objects scaled-up n times
// gttestAA.inc   objects from topo band AA
// gtcut.inc      objects default Cutter output
// includes reference objects by name, locations, rotations.
//
// The named object is defined in veg.inc (and in local m2veg.inc),
// ONE of which is included from above switch.
//
#include "gtcut_s.inc"

// GT generated camera.inc has symbollic information for terrain scale,
// camera/target parameters, and 3 lights' locations.
// Using the symbolics in this file allows live scaling and tracking
// throughout the scene, they are available to every scene object.
//
#declare cameraInclude = 1;
#if(cameraInclude)
#include "camera.inc"

// defaults when camera.inc is not used
//
#else
#declare scaleWidth  = 32;
#declare scaleLength = scaleWidth;
#declare scaleHeight = scaleWidth / 8;

// default reference camera x=24, z=24, y=2.75
//
#declare cameraX = (scaleWidth / 4) * 3;
#declare cameraZ = (scaleLength /  4) *  3;
#declare cameraY = (scaleHeight / 16) * 11;

// default reference target x=24, z=0, y=3.5
//
#declare cameraLookX = (scaleWidth  / 4) * 3;
#declare cameraLookZ = 0;
#declare cameraLookY = (scaleHeight / 4) * 3.5;

// default reference lights
//
#declare light1x = 18;
#declare light1z =  8;
#declare light1y = 15;
#declare light2x = 20;
#declare light2z = 20;
#declare light2y =  8;
#declare light3x = 24;
#declare light3z = 24;
#declare light3y =  3;
#end

// sky params
// TBD calculate these from available scale params
//
#declare SKYSCALE    =   2;
#declare CLOUDSCALE  =   0.40;
#declare CLOUDSCALEY =   0.25;

#declare levelWater = scaleHeight * 0.20;

// monitor adjustment, as required
//
global_settings {
   // assumed_gamma 2.2
   // assumed_gamma 1.8
   // assumed_gamma 1.6
   // assumed_gamma 1.4
   // assumed_gamma 1.2
   // max_trace_level 2.0
}

//////////////////
// lights & camera
//
// fake sun - visible light source orb for alignment
//
#declare sunOrbAppear = 0;
#if (sunOrbAppear)
#declare sunOrb = object {
   sphere{
      <0, 0, 0,>, 5
      texture {
        pigment {color rgb <1, 1, 1>}
        finish {ambient .8 diffuse .6}
      }
   }
}
//
object{sunOrb}
#end  // end fake sun

// trio of light sources
//
#if (1)
light_source {          // 1. main, (from right or left or whatever)
   <light1x, light1y, light1z>
   rgb <1.00, 0.995, 0.990>
   area_light <5, 0, 0>, <0, 0, 5>, 5, 5
   adaptive 1
   fade_distance 256
   fade_power 1
   // jitter
   // looks_like {sunOrb}
   // shadowless
}
#end
//
#if(1)
light_source {          // 2. light at camera location
   <light2x, light2y, light2z>
   rgb <0.75, 0.75, 0.75>
   area_light <5, 0, 0>, <0, 0, 5>, 5, 5
   adaptive 1
   fade_distance 128
   fade_power 1
   // jitter
   // looks_like {sunOrb}
   shadowless
}
#end
//
#if(1)
light_source {          // 3. back-fill
   <light3x, light3y, light3z>

   // rgb <0.825, 0.850, 0.875>  // blue
   rgb <0.875, 0.850, 0.825>  // red

   area_light <5, 0, 0>, <0, 0, 5>, 5, 5
   adaptive 1
   fade_distance 64
   fade_power 1
   // jitter
   // looks_like {sunOrb}
   shadowless
}
#end

camera {
   location <cameraX, cameraY, cameraZ>
   look_at  <cameraLookX, cameraLookY, cameraLookZ>
   // focal_point <0, 1.0,  2.5>
   // aperture 0.4
   // blur_samples 20
}

////////////////////
// terrain landscape
//
// Don't smooth or else there will be voids in the image map,
// wherever terrain has sharp edges.
//
height_field {
   tga "gfoutput.tga"
   // smooth
   texture {
      pigment {
         image_map {
            gif "gttestmap.gif" map_type 0 interpolate 2
            // gif "gttest.gif" map_type 0 interpolate 2
            once
         }
         rotate x*90
      }
      // translate <0, 0.5, 0>
   }
   finish { ambient 0.25 diffuse 0.25 }
   // translate <-0.50, 0.034, -0.5>

   scale <scaleWidth, scaleHeight, scaleLength>
}

////////////////////////////////////////////
// water, the level adjustment needs work!!!
//
#if (1)
plane {
   <0, 1, 0>, 0
   scale <scaleWidth, scaleHeight, scaleLength>
   translate <0, levelWater, 0>
   texture { TexWater }
}

#else
box {
   <0, 0, 0>, <1, 1, 1>
   scale <scaleWidth, scaleHeight, scaleLength>
   translate <0, levelWater, 0>
   texture { TexWater }
}
#end

//////
// sky
//
sky_sphere {
   pigment {   // basic sky color
      gradient y
      color_map {
         [ 0.33 color rgbt <0.20, 0.40, 0.60, 0.10> ]   // horizon
         [ 0.66 color rgbt <0.10, 0.20, 0.50, 0.10> ]
         [ 1.00 color rgbt <0.05, 0.10, 0.40, 0.10> ]   // zenith
      }
      scale SKYSCALE
      translate -(SKYSCALE / 2)
   }
   pigment {   // clouds
      bozo
      turbulence 0.85
      color_map {
         [ 0.0 color <1.00, 0.70, 0.6> ]
         // [ 0.1 color <1.00, 0.85, 0.7> ]
         // [ 0.2 color <1.00, 0.90, 0.8> ]
         [ 1.0 color <1.00, 1.00, 1.00> filter 0.95 ]
      }
      // flatten clouds
      scale <CLOUDSCALE, (CLOUDSCALE * CLOUDSCALEY), CLOUDSCALE>
      // translate -(SKYSCALE / 2)
   }
}
// fogs - primitive tests only
//
// atmospheric fog
#if (0)
fog {
   distance 10
   // 100 * t% of light passes through fog
   // minimum transluscency is 20%
   color rgbt<0.7, 0.7, 0.7, 0.5>

   // 100 * (1.0 - t)% of light through fog is filtered
   // color rgbf<0.7, 0.7, 0.7, 0.5>
   turbulence 0.5
   turb_depth 0.5
}
#end
//
// ground fog
#if (0)
fog {
   distance scaleWidth * 2
   color rgbf<0.72, 0.74, 0.76, 0.9>
   fog_type 2

   // same as water-level
   fog_offset levelWater

   fog_alt 0.05
   turbulence 1.5 // 0.4
   // lambda 1.5
   // omega 1.5 // 0.8
   // octaves 5
   // frequency 3
   turb_depth 12.5
}
#end

// --- end gttest.pov ---
